package Getopt::HashDefaults;
BEGIN {
  $Getopt::HashDefaults::AUTHORITY = 'cpan:GENE';
}
# ABSTRACT: Single declaration default settings
our $VERSION = '0.0202_POOF';
1;

__END__

=pod

=head1 NAME

Getopt::HashDefaults - Single declaration default settings

=head1 VERSION

version 0.0202

=head1 SYNOPSIS

  use Getopt::Long;
  # It already does this.

=head1 NAME

Getopt::HashDefaults - Single declaration default settings

=head1 SEE ALSO

L<Getopt::Long>

=head1 AUTHOR

Gene Boggs <gene@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2013 by Gene Boggs.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
